@@ -219,8 +219,8 @@ class SmartFilename(object):
         fields_def : OrderedDict
             Name of fields (keys) in right order and length (values). It must contain:
                 - "len": int
-                    Length of filename part (must be given).
-                    "0" to allow any length.
+                    Length (positive number) of filename part (must be given).
+                    0 to allow any length.
                 - "start": int, optional
                     Start index of filename part (default is 0).
                 - "delim": str, optional
@@ -244,39 +244,42 @@ class SmartFilename(object):
         ext = os.path.splitext(filename_str)[1]
 
         fields = dict()
-        start = 0
+        pos = 0
         for name, value in fields_def.items():
+            start = value.get('start')
+            length = value.get('len')
+            delim = value.get('delim')
+
+            if length is not None and length < 0:
+                err_msg = "The length of the attribute '{}' must be a positive number".format(name)
+                raise ValueError(err_msg)
+
             # parse part of filename via start and end position
-            if 'start' in value.keys() and 'len' in value.keys():
-                start = value['start']
-                length = value['len']
+            if start is not None and length is not None:
                 fields[name] = filename_str[start:(start + length)]
-            elif 'len' in value.keys():
+            elif length is not None:
+                start = pos
                 if compact:
                     length = 0
-                    if 'delim' in value.keys():
-                        if not value['delim']:
-                            raise Exception('The compact filename design requires a delimiter for each field!')
-                    elif not delimiter:
+                    if delim is None and delimiter is None:
                         raise Exception('The compact filename design requires a delimiter for each field!')
-                else:
-                    length = value['len']
+
                 if length == 0:  # handle variable length
                     end = filename_str.find(delimiter, start) if delimiter in filename_str[start:] \
                         else filename_str.find('.', start)
                     length = end - start
                 # if length is not 0, i.e. an entry is available, then add the field. Otherwise skip it.
-                if length != 0:
+                if length > 0:
                     fields[name] = filename_str[start:(start + length)]
             else:
                 length = 0
 
-            start += length
+            pos += length
 
-            if 'delim' in value.keys():
-                start += len(value['delim'])
+            if delim is not None:
+                pos += len(delim)
             else:
-                start += len(delimiter)
+                pos += len(delimiter)
 
         if cls.__name__ == "SmartFilename":
             return cls(fields, fields_def, ext=ext, convert=convert, pad=pad, delimiter=delimiter)
@@ -318,8 +321,8 @@ class SmartFilename(object):
         fields_def : OrderedDict
             Name of fields (keys) in right order and length (values). It must contain:
                 - "len": int
-                    Length of filename part (must be given).
-                    "0" to allow any length.
+                    Length (positive number) of filename part (must be given).
+                    0 to allow any length.
                 - "start": int, optional
                     Start index of filename part (default is 0).
                 - "delim": str, optional
@@ -358,6 +361,10 @@ class SmartFilename(object):
                     err_msg = 'A variable field length (length = 0) requires a delimiter!'
                     raise ValueError(err_msg)
 
+                if keys['len'] < 0:
+                    err_msg = "The length of the attribute '{}' must be a positive number".format(name)
+                    raise ValueError(err_msg)
+
                 fn_part_kwargs['length'] = keys['len']
 
             if 'decoder' in keys:
@@ -366,7 +373,7 @@ class SmartFilename(object):
                 fn_part_kwargs['encoder'] = keys['encoder']
             fn_part_kwargs['compact'] = self.compact
 
-            if last_key_name == name:  # set empty delimiter for last field
+            if name == last_key_name:  # set empty delimiter for last field
                 fn_part_kwargs['delimiter'] = ''
 
             # reset delimiter of last element to be empty
@@ -387,8 +394,13 @@ class SmartFilename(object):
         """
 
         fn_parts = list(self._fn_map.values())
+
         filename = ''.join([repr(fn_part) for fn_part in fn_parts])
 
+        # handle case if last field is not defined (skip the last delimeter then)
+        if filename.endswith(self.delimiter):
+            filename = filename[:-1]
+
         if self.ext is not None:
             filename += self.ext
 
